@@ -23,6 +23,7 @@ from .output_checker import (FIX, IGNORE_WARNINGS, REMOTE_DATA, SHOW_WARNINGS,
 _pytest_version = Version(pytest.__version__)
 PYTEST_GT_5 = _pytest_version > Version('5.9.9')
 PYTEST_GE_6_3 = _pytest_version.is_devrelease or _pytest_version >= Version('6.3')
+PYTEST_GT_6_3 = _pytest_version.is_devrelease or _pytest_version > Version('6.3')
 
 comment_characters = {
     '.txt': '#',
@@ -89,9 +90,9 @@ def pytest_addoption(parser):
 
     parser.addoption("--text-file-format", action="store",
                      help=(
-                        "Text file format for narrative documentation. "
-                        "Options accepted are 'txt', 'tex', and 'rst'. "
-                        "This is no longer recommended, use --doctest-glob instead."
+                         "Text file format for narrative documentation. "
+                         "Options accepted are 'txt', 'tex', and 'rst'. "
+                         "This is no longer recommended, use --doctest-glob instead."
                      ))
 
     # Defaults to `atol` parameter from `numpy.allclose`.
@@ -139,8 +140,8 @@ def pytest_addoption(parser):
                   default=[])
 
     parser.addini("doctest_subpackage_requires",
-                  "A list of paths to skip if requirements are not satisfied. Each item in the list "
-                  "should have the syntax path=req1;req2",
+                  "A list of paths to skip if requirements are not satisfied."
+                  "Each item in the list should have the syntax path=req1;req2",
                   type='linelist',
                   default=[])
 
@@ -156,7 +157,8 @@ def get_optionflags(parent):
 def pytest_configure(config):
     doctest_plugin = config.pluginmanager.getplugin('doctest')
     run_regular_doctest = config.option.doctestmodules and not config.option.doctest_plus
-    use_doctest_plus = config.getini('doctest_plus') or config.option.doctest_plus or config.option.doctest_only
+    use_doctest_plus = config.getini(
+        'doctest_plus') or config.option.doctest_plus or config.option.doctest_only
     if doctest_plugin is None or run_regular_doctest or not use_doctest_plus:
         return
 
@@ -189,12 +191,23 @@ def pytest_configure(config):
         def collect(self):
             # When running directly from pytest we need to make sure that we
             # don't accidentally import setup.py!
-            if self.fspath.basename == "setup.py":
+            if PYTEST_GE_6_3:
+                fspath = self.path
+                filepath = self.path.name
+            else:
+                fspath = self.fspath
+                filepath = self.fspath.basename
+
+            if filepath == "setup.py":
                 return
-            elif self.fspath.basename == "conftest.py":
-                if PYTEST_GE_6_3:
+            elif filepath == "conftest.py":
+                if PYTEST_GT_6_3:
                     module = self.config.pluginmanager._importconftest(
-                        Path(self.fspath), self.config.getoption("importmode"))
+                        self.path, self.config.getoption("importmode"),
+                        rootpath=self.config.rootpath)
+                elif PYTEST_GE_6_3:
+                    module = self.config.pluginmanager._importconftest(
+                        self.path, self.config.getoption("importmode"))
                 elif PYTEST_GT_5:
                     module = self.config.pluginmanager._importconftest(
                         self.fspath, self.config.getoption("importmode"))
@@ -203,10 +216,18 @@ def pytest_configure(config):
                         self.fspath)
             else:
                 try:
-                    module = self.fspath.pyimport()
+                    if PYTEST_GT_5:
+                        from _pytest.pathlib import import_path
+
+                    if PYTEST_GE_6_3:
+                        module = import_path(fspath, root=self.config.rootpath)
+                    elif PYTEST_GT_5:
+                        module = import_path(fspath)
+                    else:
+                        module = fspath.pyimport()
                 except ImportError:
                     if self.config.getvalue("doctest_ignore_import_errors"):
-                        pytest.skip("unable to import module %r" % self.fspath)
+                        pytest.skip("unable to import module %r" % fspath)
                     else:
                         raise
 
@@ -219,38 +240,36 @@ def pytest_configure(config):
 
             for test in finder.find(module):
                 if test.examples:  # skip empty doctests
-                    if config.getoption('remote_data', 'none') != 'any':
+                    ignore_warnings_context_needed = False
+                    show_warnings_context_needed = False
 
-                        ignore_warnings_context_needed = False
-                        show_warnings_context_needed = False
+                    for example in test.examples:
+                        if (config.getoption('remote_data', 'none') != 'any'
+                                and example.options.get(REMOTE_DATA)):
+                            example.options[doctest.SKIP] = True
 
-                        for example in test.examples:
+                        # If warnings are to be ignored we need to catch them by
+                        # wrapping the source in a context manager.
+                        elif example.options.get(IGNORE_WARNINGS, False):
+                            example.source = ("with _doctestplus_ignore_all_warnings():\n"
+                                              + indent(example.source, '    '))
+                            ignore_warnings_context_needed = True
 
-                            # If warnings are to be ignored we need to catch them by
-                            # wrapping the source in a context manager.
-                            if example.options.get(IGNORE_WARNINGS, False):
-                                example.source = ("with _doctestplus_ignore_all_warnings():\n"
-                                                  + indent(example.source, '    '))
-                                ignore_warnings_context_needed = True
+                        # Same for SHOW_WARNINGS
+                        elif example.options.get(SHOW_WARNINGS, False):
+                            example.source = ("with _doctestplus_show_all_warnings():\n"
+                                              + indent(example.source, '    '))
+                            show_warnings_context_needed = True
 
-                            # Same for SHOW_WARNINGS
-                            if example.options.get(SHOW_WARNINGS, False):
-                                example.source = ("with _doctestplus_show_all_warnings():\n"
-                                                  + indent(example.source, '    '))
-                                show_warnings_context_needed = True
+                    # We insert the definition of the context manager to ignore
+                    # warnings at the start of the file if needed.
+                    if ignore_warnings_context_needed:
+                        test.examples.insert(0, doctest.Example(
+                            source=IGNORE_WARNINGS_CONTEXT, want=''))
 
-                            if example.options.get(REMOTE_DATA):
-                                example.options[doctest.SKIP] = True
-
-                        # We insert the definition of the context manager to ignore
-                        # warnings at the start of the file if needed.
-                        if ignore_warnings_context_needed:
-                            test.examples.insert(0, doctest.Example(
-                                source=IGNORE_WARNINGS_CONTEXT, want=''))
-
-                        if show_warnings_context_needed:
-                            test.examples.insert(0, doctest.Example(
-                                source=SHOW_WARNINGS_CONTEXT, want=''))
+                    if show_warnings_context_needed:
+                        test.examples.insert(0, doctest.Example(
+                            source=SHOW_WARNINGS_CONTEXT, want=''))
 
                     try:
                         yield doctest_plugin.DoctestItem.from_parent(
@@ -264,10 +283,16 @@ def pytest_configure(config):
     class DocTestTextfilePlus(pytest.Module):
 
         def collect(self):
+            if PYTEST_GE_6_3:
+                fspath = self.path
+                filepath = self.path.name
+            else:
+                fspath = self.fspath
+                filepath = self.fspath.basename
+
             encoding = self.config.getini("doctest_encoding")
-            text = self.fspath.read_text(encoding)
-            filename = str(self.fspath)
-            name = self.fspath.basename
+            text = fspath.read_text(encoding)
+            filename = str(fspath)
             globs = {"__name__": "__main__"}
 
             optionflags = get_optionflags(self) | FIX
@@ -276,7 +301,7 @@ def pytest_configure(config):
                 verbose=False, optionflags=optionflags, checker=OutputChecker())
 
             parser = DocTestParserPlus()
-            test = parser.get_doctest(text, globs, name, filename, 0)
+            test = parser.get_doctest(text, globs, filepath, filename, 0)
             if test.examples:
                 try:
                     yield doctest_plugin.DoctestItem.from_parent(
@@ -300,6 +325,9 @@ def pytest_configure(config):
              installed.
 
            - ``.. doctest-skip-all``: Skip all subsequent doctests.
+
+           - ``.. doctest-remote-data::``: Skip the next doctest chunk if
+             --remote-data is not passed.
         """
 
         def parse(self, s, name=None):
@@ -331,7 +359,8 @@ def pytest_configure(config):
                     required = []
                     skip_next = False
                     lines = entry.strip().splitlines()
-                    if any([re.match('{} doctest-skip-all'.format(comment_char), x.strip()) for x in lines]):
+                    if any(re.match(
+                            '{} doctest-skip-all'.format(comment_char), x.strip()) for x in lines):
                         skip_all = True
                         continue
 
@@ -358,6 +387,15 @@ def pytest_configure(config):
                             skip_next = True
                             continue
 
+                    if config.getoption('remote_data', 'none') != 'any':
+                        matches = (re.match(
+                            r'{}\s+doctest-remote-data\s*::'.format(comment_char),
+                            last_line) for last_line in last_lines)
+
+                        if any(matches):
+                            skip_next = True
+                            continue
+
                     matches = [re.match(
                         r'{}\s+doctest-requires\s*::\s+(.*)'.format(comment_char),
                         last_line) for last_line in last_lines]
@@ -372,26 +410,27 @@ def pytest_configure(config):
                         required = re.split(r'\s*[,\s]\s*', match.group(1))
                 elif isinstance(entry, doctest.Example):
 
+                    has_required_modules = DocTestFinderPlus.check_required_modules(required)
+                    if skip_all or skip_next or not has_required_modules:
+                        entry.options[doctest.SKIP] = True
+
+                    elif (config.getoption('remote_data', 'none') != 'any'
+                            and entry.options.get(REMOTE_DATA)):
+                        entry.options[doctest.SKIP] = True
+
                     # If warnings are to be ignored we need to catch them by
                     # wrapping the source in a context manager.
-                    if entry.options.get(IGNORE_WARNINGS, False):
+                    elif entry.options.get(IGNORE_WARNINGS, False):
                         entry.source = ("with _doctestplus_ignore_all_warnings():\n"
                                         + indent(entry.source, '    '))
                         ignore_warnings_context_needed = True
 
                     # Same to show warnings
-                    if entry.options.get(SHOW_WARNINGS, False):
+                    elif entry.options.get(SHOW_WARNINGS, False):
                         entry.source = ("with _doctestplus_show_all_warnings():\n"
                                         + indent(entry.source, '    '))
                         show_warnings_context_needed = True
 
-                    has_required_modules = DocTestFinderPlus.check_required_modules(required)
-                    if skip_all or skip_next or not has_required_modules:
-                        entry.options[doctest.SKIP] = True
-
-                    if config.getoption('remote_data', 'none') != 'any' and entry.options.get(REMOTE_DATA):
-                        entry.options[doctest.SKIP] = True
-
             # We insert the definition of the context manager to ignore
             # warnings at the start of the file if needed.
             if ignore_warnings_context_needed:
@@ -439,7 +478,14 @@ class DoctestPlus(object):
             dirpath = Path(path).parent
         else:
             dirpath = path.dirpath()
-        collect_ignore = config._getconftest_pathlist("collect_ignore", path=dirpath)
+
+        try:
+            collect_ignore = config._getconftest_pathlist("collect_ignore", path=dirpath)
+        except TypeError:
+            # Pytest 7.0+
+            collect_ignore = config._getconftest_pathlist("collect_ignore",
+                                                          path=dirpath,
+                                                          rootpath=config.rootpath)
 
         # The collect_ignore conftest.py variable should cause all test
         # runners to ignore this file and all subfiles and subdirectories
